'****************************************************************************
'*                                                                          *
'*  caprodregxml.vbs - Display registry values from CA products in XML	    *
'*                                                                          *
'*  By default, caprodregxml produces an xml file in the current directory  *
'*  named 'caprodinfo.xml' and writes this file name to stdout.  If you     *
'*  specify the argument 'stdout', the information is written as a text	    *
'*  description to standard output.                                         *
'*                                                                          *
'****************************************************************************
const HKLM = &H80000002
const REG_SZ = 1
const REG_EXPAND_SZ = 2
const REG_BINARY = 3
const REG_DWORD = 4
const REG_MULTI_SZ = 7

Dim infofile, filetxt
const xmlfile = "caprodinfo.xml"
Set infofile = CreateObject("Scripting.FileSystemObject")
Set filetext = infofile.CreateTextFile(xmlfile, True)
If Wscript.Arguments.Count > 0 Then
	If Wscript.Arguments.Item(0) = "stdout" Then
		xmlout = False
	Else
		xmlout = True
	End If
Else
	xmlout = True
End If
If xmlout Then
	Wscript.Echo infofile.GetAbsolutePathName(xmlfile)
End If

Sub EchoKeyValues(RegObj, DefKey, SubKeyName)
	On error Resume Next
	If xmlout Then
		sTitle = Replace(SubKeyName,"&","+")
		sTitle = Replace(sTitle,"""","'")
		sTitle = Replace(sTitle,""," ")
		sTitle = Replace(sTitle,""," ")
		sTitle = Replace(sTitle,"","e")
		filetext.WriteLine("<folder title=""" & sTitle & """ expanded=""false"" img=""folder.gif"">")
	Else
		Wscript.Echo vbCrLf & vbtab & "Subkey: " & SubKeyName & vbCrLf
	End If
	RegObj.EnumValues DefKey, SubKeyName, eValues, eTypes

	For i=0 to UBound(eValues)
		Select Case eTypes(i)

			Case REG_SZ
				RegObj.GetStringValue DefKey, SubKeyName,_
					eValues(i), sValue
				If eValues(i) = "" Then
					eValues(i) = "(Default)"
				End If
				sValue = Replace(sValue,"&","+")
				sValue = Replace(sValue,"""","'")
				sValue = Replace(sValue,""," ")
				sValue = Replace(sValue,""," ")
				sValue = Replace(sValue,"","e")
				if xmlout Then
				filetext.WriteLine("<leaf title=""" &_
					 eValues(i) & " - STRING - '" &_
					sValue & "'"" img=""regsz.gif""/>")
				Else
				Wscript.Echo vbTab & vbTab & _
					"Key: " & eValues(i) & " Value SZ '" &_
					sValue & "'"
				End If

			Case REG_EXPAND_SZ
				RegObj.GetExpandedStringValue DefKey, _
					SubKeyName,_
					eValues(i), esValue
				if xmlout Then
				filetext.WriteLine("<leaf title=""" &_
					 eValues(i) & " - EXSTRING - '" &_
					esValue & "'"" img=""regsz.gif""/>")
				Else
				Wscript.Echo vbTab & vbTab & _
					"Key: " & eValues(i) & " Value EXP_SZ '" &_
					esValue & "'"
				End If

			Case REG_BINARY
				RegObj.GetBinaryValue DefKey, _
					SubKeyName,_
					eValues(i), bValue
				if xmlout Then
				filetext.WriteLine("<leaf title=""" &_
					 eValues(i) & " - BINARY - '" &_
					bValue & "'"" img=""regdword.gif""/>")
				Else
				Wscript.Echo vbTab & vbTab & _
					"Key: " & eValues(i) & " Value BIN '" &_
					bValue & "'"
				End If

			Case REG_DWORD
				RegObj.GetDWORDValue DefKey, _
					SubKeyName,_
					eValues(i), dwValue
				If xmlout Then
				filetext.WriteLine("<leaf title=""" &_
					 eValues(i) & " - DWORD - " &_
					dwValue & """ img=""regdword.gif""/>")
				Else
				Wscript.Echo vbTab & vbTab & _
					"Key: " & eValues(i) & " Value DWORD '" &_
					dwValue & "'"
				End If

			Case REG_MULTI_SZ
				RegObj.GetMultiStringValue DefKey, _
					SubKeyName,_
					eValues(i), msValue
				if xmlout Then
				filetext.WriteLine("<leaf title=""" &_
					 eValues(i) & " - MSTRING - '" &_
					msValue & "'"" img=""regsz.gif""/>")
				Else
				Wscript.Echo vbTab & vbTab & _
					"Key: " & eValues(i) & " Value MULT_SZ '" &_
					msValue & "'"
				End If
		End Select 
	Next
	
'	Wscript.Echo vbtab & "Subkeys for " & SubKeyName & ":"
	RegObj.EnumKey DefKey, SubKeyName, eKeys
	For Each subkey in eKeys
		If subkey > "" Then _
			EchoKeyValues RegObj, DefKey, SubKeyName & "\" & subkey
	Next
	If xmlout Then
		filetext.WriteLine("</folder>")
	End If

End Sub

Set WshShell = WScript.CreateObject("WScript.Shell")
Set wmi = GetObject("winmgmts:")
Set RegProv = GetObject("winmgmts:root/DEFAULT:StdRegProv")


if xmlout Then
filetext.WriteLine("<?xml version=""1.0"" encoding=""UTF-8""?>")
filetext.WriteLine("<!DOCTYPE treeview SYSTEM ""treeview.dtd"">")
filetext.WriteLine("")
filetext.WriteLine("<?xml-stylesheet type=""text/xsl"" href=""treeview.xslt""?>")
filetext.WriteLine("<treeview title=""Windows XP Explorer Treeview"">")
End If

RegProv.EnumKey HKLM, "SOFTWARE\ComputerAssociates\", sKeys
On error Resume Next

For Each cakey In sKeys
	If NOT xmlout Then
		Wscript.Echo vbCrLf & "CA Product: " & cakey
	End If
	EchoKeyValues RegProv, HKLM, "SOFTWARE\ComputerAssociates\" & cakey
Next

RegProv.EnumKey HKLM, "SOFTWARE\CA\", sKeys
On error Resume Next
For Each cakey In sKeys
	If NOT xmlout Then
		Wscript.Echo vbCrLf & "CA Product: " & cakey
	End If
	EchoKeyValues RegProv, HKLM, "SOFTWARE\CA\" & cakey
Next

If xmlout Then
	filetext.WriteLine("</treeview>")
End If
